@@ -45,16 +45,26 @@ class Html
 	 * @param   string  $name        Field name
 	 * @return  string  HTML <select>
 	 */
-	public static function sectionSelect($categories, $val, $name, $id='')
+	public static function categories($categories, $val, $name, $id = null, $atts = null)
 	{
-		$out  = '<select name="' . $name . '" id="' . ($id ? $id : str_replace(array('[', ']'), '', $name)) . '">';
+		$out  = '<select name="' . $name . '" id="' . ($id ? $id : str_replace(array('[', ']'), '', $name)) . '"' . ($atts ? ' ' . $atts : '') . '>';
 		$out .= '<option value="">' . \Lang::txt('COM_KB_SELECT_CATEGORY') . '</option>';
 		foreach ($categories as $category)
 		{
 			$selected = ($category->get('id') == $val)
 					  ? ' selected="selected"'
 					  : '';
-			$out .= '<option value="' . $category->get('id') . '"' . $selected . '>' . stripslashes($category->get('title')) . '</option>';
+			$prfx = '';
+
+			if ($category->get('level') > 1)
+			{
+				for ($i = 1; $i <= $category->get('level'); $i++)
+				{
+					$prfx .= '- ';
+				}
+			}
+
+			$out .= '<option value="' . $category->get('id') . '"' . $selected . '>' . $prfx . stripslashes($category->get('title')) . '</option>';
 		}
 		$out .= '</select>';
 		return $out;
