@@ -2,8 +2,8 @@
 
 use Hubzero\Content\Migration\Base;
 
-// Check to ensure this file is included in Joomla!
-defined('_JEXEC') or die('Restricted access');
+// No direct access
+defined('_HZEXEC_') or die();
 
 /**
  * Migration script for languages table addition
@@ -17,7 +17,7 @@ class Migration20150826245312Core extends Base
 	{
 		if ($this->db->tableExists('#__languages'))
 		{
-			$query = "UPDATE #__languages SET access=1 WHERE lang_id=1 AND access=0;";
+			$query = "UPDATE `#__languages` SET access=1 WHERE lang_id=1 AND access=0;";
 			$this->db->setQuery($query);
 			$this->db->query();
 		}
