@@ -60,7 +60,8 @@ class Helper extends Module
 			'start'    => 0,
 			'scope'    => $this->params->get('blog', 'site'),
 			'scope_id' => 0,
-			'state'    => (!User::isGuest() ? 'registered' : 'public')
+			'state'    => 1,
+			'access'   => User::getAuthorisedViewLevels()
 		);
 		if ($filters['scope'] == 'both' || $filters['scope'] == 'group')
 		{
@@ -72,13 +73,17 @@ class Helper extends Module
 		}
 
 		$archive = new Archive('site', 0);
-		$rows = $archive->entries('list', $filters);
+		$rows = $archive->entries($filters)
+			->ordered()
+			->rows();
 
-		if ($this->params->get('blog', 'site') == 'group' || $this->params->get('blog', 'site') == 'both')
+		$posts = array();
+
+		foreach ($rows as $k => $gf)
 		{
-			//make sure that the group for each blog post has the right privacy setting
-			foreach ($rows as $k => $gf)
+			if ($this->params->get('blog', 'site') == 'group' || $this->params->get('blog', 'site') == 'both')
 			{
+				//make sure that the group for each blog post has the right privacy setting
 				if (!$gf->get('scope_id'))
 				{
 					continue;
@@ -93,18 +98,19 @@ class Helper extends Module
 					 || ($blog_access == 'registered' && User::isGuest())
 					 || ($blog_access == 'members' && !in_array(User::get('id'), $group->get('members'))))
 					{
-						$rows->offsetUnset($k);
+						continue;
 					}
 				}
 				else
 				{
-					$rows->offsetUnset($k);
+					continue;
 				}
 			}
-		}
-		$rows->reset();
 
-		$this->posts = $rows;
+			$posts[] = $gf;
+		}
+
+		$this->posts = $posts;
 
 		require $this->getLayoutPath();
 	}
