@@ -35,7 +35,7 @@ $this->css()
      ->js();
 ?>
 
-<form action="<?php echo Route::url($this->member->getLink() . '&active=messages&task=archive'); ?>" method="post">
+<form action="<?php echo Route::url($this->member->link() . '&active=messages&task=archive'); ?>" method="post">
 
 	<div id="filters">
 		<input type="hidden" name="inaction" value="archive" />
@@ -100,7 +100,7 @@ $this->css()
 						$component = (substr($row->component, 0, 4) == 'com_') ? substr($row->component, 4) : $row->component;
 
 						//url to view message
-						$url = Route::url($this->member->getLink() . '&active=messages&msg=' . $row->id);
+						$url = Route::url($this->member->link() . '&active=messages&msg=' . $row->id);
 
 						//get the message subject
 						$subject = $row->subject;
@@ -139,7 +139,7 @@ $this->css()
 						$date = Date::of($row->created)->toLocal(Lang::txt('DATE_FORMAT_HZ1'));
 
 						//delete link
-						$del_link = Route::url($this->member->getLink() . '&active=messages&mid[]=' . $row->id . '&action=sendtotrash&activetab=archive&' . Session::getFormToken() . '=1');
+						$del_link = Route::url($this->member->link() . '&active=messages&mid[]=' . $row->id . '&action=sendtotrash&activetab=archive&' . Session::getFormToken() . '=1');
 						$delete = '<a title="' . Lang::txt('PLG_MEMBERS_MESSAGES_REMOVE_MESSAGE') . '" class="trash" href="' . $del_link . '">' . Lang::txt('PLG_MEMBERS_MESSAGES_TRASH') . '</a>';
 					?>
 
