@@ -94,39 +94,48 @@ class plgSearchWiki extends \Hubzero\Plugin\Plugin
 		$rows = new \Components\Search\Models\Basic\Result\Sql(
 			"SELECT
 				wp.title,
+				wp.scope,
+				wp.scope_id,
 				wv.pagehtml AS description,
 				CASE
-					WHEN wp.group_cn LIKE 'pr-%' THEN concat('index.php?option=com_projects&scope=', wp.scope, '&pagename=', wp.pagename)
-					WHEN wp.group_cn != '' THEN concat('index.php?option=com_groups&scope=', wp.scope, '&pagename=', wp.pagename)
-					ELSE concat('index.php?option=com_wiki&scope=', wp.scope, '&pagename=', wp.pagename)
+					WHEN wp.path != '' THEN concat(wp.path, '/', wp.pagename)
+					ELSE wp.pagename
 				END AS link,
 				$weight AS weight,
 				wv.created AS date,
 				CASE
-					WHEN wp.group_cn LIKE 'pr-%' THEN 'Project Notes'
+					WHEN wp.scope='project' THEN 'Project Notes'
 					ELSE 'Wiki'
 				END AS section
-			FROM `#__wiki_version` wv
-			INNER JOIN `#__wiki_page` wp
-				ON wp.id = wv.pageid
-			LEFT JOIN `#__xgroups` xg ON xg.cn = wp.group_cn
+			FROM `#__wiki_versions` wv
+			INNER JOIN `#__wiki_pages` wp
+				ON wp.id = wv.page_id
+			LEFT JOIN `#__xgroups` xg ON xg.gidNumber = wp.scope_id AND wp.scope='group'
 			WHERE
 				$authorization AND
 				$weight > 0 AND
 				wp.state < 2 AND
-				wv.id = (SELECT MAX(wv2.id) FROM `#__wiki_version` wv2 WHERE wv2.pageid = wv.pageid) " .
+				wv.id = (SELECT MAX(wv2.id) FROM `#__wiki_versions` wv2 WHERE wv2.page_id = wv.page_id) " .
 				($addtl_where ? ' AND ' . join(' AND ', $addtl_where) : '') .
 				" AND (xg.gidNumber IS NULL OR (" . implode(' OR ', $groupAuth) . "))
 			 ORDER BY $weight DESC"
 		);
 
+		include_once(Component::path('com_wiki') . DS . 'models' . DS . 'page.php');
+
 		foreach ($rows->to_associative() as $row)
 		{
 			if (!$row)
 			{
 				continue;
 			}
-			$row->set_link(Route::url($row->get_raw_link()));
+
+			$page = \Components\Wiki\Models\Page::blank();
+			$page->set('pagename', $row->link);
+			$page->set('scope', $row->scope);
+			$page->set('scope_id', $row->scope_id);
+
+			$row->set_link(Route::url($page->link()));
 			// rough de-wikifying. probably a bit faster than rendering to html and then stripping the tags, but not perfect
 			//$row->set_description(preg_replace('/(\[+.*?\]+|\{+.*?\}+|[=*])/', '', $row->get_description()));
 			$row->set_description(strip_tags($row->get_description()));
@@ -134,4 +143,3 @@ class plgSearchWiki extends \Hubzero\Plugin\Plugin
 		}
 	}
 }
-
